# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-29 06:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0030_userclass_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='userclass',
            name='passed_at',
            field=models.DateTimeField(null=True, verbose_name='\u7ed3\u4e1a\u65f6\u95f4'),
        ),
    ]
