# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-23 09:15
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0034_auto_20190923_1715'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userleaverecord',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
