# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-09 06:54
from __future__ import unicode_literals

from django.db import migrations
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0027_auto_20190807_1410'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userprofile',
            name='avatar',
            field=imagekit.models.fields.ProcessedImageField(blank=True, null=True, upload_to='avatars', verbose_name='\u5934\u50cf'),
        ),
    ]
