# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-19 07:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0029_auto_20190812_1820'),
    ]

    operations = [
        migrations.AddField(
            model_name='userclass',
            name='status',
            field=models.IntegerField(choices=[(1, '\u6b63\u5e38'), (2, '\u5df2\u7ed3\u4e1a')], default=1, verbose_name='\u73ed\u7ea7\u72b6\u6001'),
        ),
    ]
