# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-07 06:10
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0026_auto_20190630_1758'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='agent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='agent_user', to='bee_django_user.UserProfile'),
        ),
        migrations.AddField(
            model_name='userprofile',
            name='gensee_room_id',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u76f4\u64ad\u95f4ID'),
        ),
        migrations.AddField(
            model_name='userprofile',
            name='wxservice_openid',
            field=models.CharField(blank=True, max_length=180, null=True),
        ),
    ]
