{% extends "bee_django_user/base.html" %}
{% load bee_django_user_filter %}

{% block content %}
    {% include 'bee_django_user/logo.html' %}
    {% include 'bee_django_user/nav.html' %}

    <div class="text-center"><h3>
        权限重置错误结果
    </h3>
    </div>
    {#    <div class="text-right">#}
    {#        <a class="btn btn-default" href="{% url 'bee_django_exam:notice_add' %}">添加须知</a>#}
    {#    </div>#}

    <table class="table">
    <thead>
        <tr>
            <th>app_label</th>
            <th>model</th>
            <th>codename</th>
            <th>错误</th>

        </tr>
        </thead>
        <tbody>
        {% for error in error_list %}
            <tr>
                <td>{{ error.app_label }}</td>
                <td>{{ error.model }}</td>
                <td>{{ error.codename }}</td>
                <td>{{ error.msg }}</td>
            </tr>

        {% endfor %}
        </tbody>
    </table>
{% endblock %}
{% block scripts %}
{% endblock %}