# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-12 05:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0036_userprofile_live_mins'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userclass',
            name='lecturer',
        ),
        migrations.AddField(
            model_name='userprofile',
            name='lecturer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='lecturer_user', to='bee_django_user.UserProfile', verbose_name='\u8bb2\u5e08'),
        ),
    ]
